@@ -379,7 +379,7 @@ get_dplyr_groups <- function(x, group) {
 
   dplyr_groups <- dplyr::groups(x)
 
-  if (is.null(dplyr_groups)) {
+  if (is.null(dplyr_groups)) {F
     return(group)
   } else {
     dplyr_groups <- as.character(dplyr_groups)
