@@ -98,3 +98,48 @@ test_that("assure_greater_than_max_x works properly", {
   expect_equal( assure_greater_than_max_x(max_x_posix, end_val_posix, "day"),
                 as.POSIXct("2016-10-21 14:39:04"))
 })
+
+test_that("span integration tests", {
+  x <- coffee$time_stamp[3:4]
+  sp <- function(interval) span(x, list(interval = interval, step = 1))
+  expect_equal(sp("year"), span_date(2016, 2017))
+  expect_equal(sp("quarter"), as.Date(c("2016-07-01", "2016-10-01")))
+  expect_equal(sp("month"), span_date(201607, 201608))
+  expect_equal(sp("week"), as.Date(c("2016-07-03", "2016-07-10", "2016-07-17")))
+  expect_equal(sp("day"), span_date(20160709, 20160711))
+})
+
+context("span_around function")
+
+test_that("span_around breaks on the wrong input", {
+  expect_error(span_around(coffee, "hour"))
+  expect_error(span_around(coffee$time_stamp, "hour"), NA)
+  expect_error(span_around(coffee$time_stamp, "hour", start_shift = 12))
+  expect_error(span_around(coffee$time_stamp, "hour", start_shift = "12 hour"), NA)
+  expect_error(span_around(coffee$time_stamp, "hour", end_shift = 12))
+  expect_error(span_around(coffee$time_stamp, "hour", end_shift = "12 hour"), NA)
+})
+
+
+test_that("span_around integration tests", {
+  x <- as.POSIXct(c("2016-07-09 13:25:17", "2016-07-10 10:45:11"), tz = "CET")
+  start_shift_one_hour <- span_around(x, "hour", start_shift = "1 hour")
+  end_shift_one_hour <- span_around(x, "hour", end_shift = "1 hour")
+  expect_error(span_around(1:10, "day"))
+  expect_error(span_around(x, "day"), NA)
+  expect_error(span_around(x, "2 days"), NA)
+  expect_equal(span_around(x, "day"), span_date(20160709, 20160711))
+  expect_equal(span_around(x, "hour"),
+               span_time("20160709 13", "20160710 11", tz = "CET"))
+  expect_equal(span_around(x, "min"),
+               span_time("20160709 13", "20160710 1046", tz = "CET"))
+  expect_equal(start_shift_one_hour[1],
+               as.POSIXct("2016-07-09 12:00:00", tz = "CET"))
+  expect_equal(start_shift_one_hour[length(start_shift_one_hour)],
+               as.POSIXct("2016-07-10 12:00:00", tz = "CET"))
+  expect_equal(end_shift_one_hour[1],
+               as.POSIXct("2016-07-09 13:00:00", tz = "CET"))
+  expect_equal(end_shift_one_hour[length(end_shift_one_hour)],
+               as.POSIXct("2016-07-10 12:00:00", tz = "CET"))
+  expect_equal(span_around(x, "day", start_shift = "1 day")[1], as.Date("2016-07-08"))
+})
